# -*- coding: utf-8 -*-
from django.dispatch import Signal

pre_transition = Signal()
post_transition = Signal()
